/**
 * This file is part of GenomeView, a genome browser and annotation curator
 * 
 * Copyright (C) 2007-2017 Thomas Abeel and contributors
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Project: http://genomeview.org/
 */
package net.sf.jannot.pileup;

/**
 * @author Thomas Abeel
 * 
 */
public class DoublePile extends SinglePile {
	public DoublePile(int pos, float val0, float val1) {
		super(pos, val0);
		this.val1 = val1;

	}

	private float val1;

	/*
	 * (non-Javadoc)
	 * 
	 * @see net.sf.jannot.pileup.SinglePile#getValueCount()
	 */
	@Override
	public int getValueCount() {
		return 2;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see net.sf.jannot.pileup.SinglePile#getValue(int)
	 */
	@Override
	public float getValue(int i) {
		if (i == 0)
			return super.getValue(0);
		else if (i == 1)
			return val1;
		else
			throw new IndexOutOfBoundsException(
					"DoublePile only supports two value, you requested the value with index " + i);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see net.sf.jannot.pileup.SinglePile#getTotal()
	 */
	@Override
	public float getTotal() {
		return getValue(0) + getValue(1);
	}

}
