/**
 * This file is part of GenomeView, a genome browser and annotation curator
 * 
 * Copyright (C) 2007-2017 Thomas Abeel and contributors
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Project: http://genomeview.org/
 */
package net.sf.jannot.tabix;

/**
 * Pair of longs
 * 
 * @author Thomas Abeel, Thomas Van Parys
 * 
 */
public class Pair64 implements Comparable<Pair64>{
	/**
	 * Pair value
	 */
	public long start, end;

	public Pair64(long u, long v) {
		this.start = u;
		this.end = v;
	}

	@Override
	public int compareTo(Pair64 o) {
		long a = this.start;
		long b = o.start;
		if (a < b)
			return -1;
		else if (a == b)
			return 0;
		else
			return 1;
	}

	@Override
	public String toString() {
		final long compressedOffset = start >> 16;
		final int uncompressedOffset = (int) (start & 0xFFFF);
		final long compressedOffsetE = end >> 16;
		final int uncompressedOffsetE = (int) (end & 0xFFFF);
		return compressedOffset + "," + uncompressedOffset + "\t" + compressedOffsetE + "," + uncompressedOffsetE;
	}

}

