/**
 * This file is part of GenomeView, a genome browser and annotation curator
 * 
 * Copyright (C) 2007-2017 Thomas Abeel and contributors
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Project: http://genomeview.org/
 */
package net.sf.jannot.wiggle;

import net.sf.jannot.utils.ArrayIterable;

/**
 * 
 * @author Thomas Abeel
 * 
 */
public class FloatArrayWiggle extends AbstractWiggle {

	private float[] buffer;
	// private String name;
	private float min = Float.POSITIVE_INFINITY;
	private float max = Float.NEGATIVE_INFINITY;

	public FloatArrayWiggle(float[] arr) {
		// this.name = name;
		this.buffer = arr;
		for (float f : arr) {
			if (f > max)
				max = f;
			if (f < min)
				min = f;
		}
		super.init(this);

	}

	//
	// @Override
	// public String getName() {
	// return name;
	// }

	@Override
	public float[] getRawRange(int start, int end) {
		if (start >= buffer.length)
			return new float[0];
		float[] out = new float[end - start];
		int len = out.length;
		if (start + len > buffer.length)
			len = buffer.length - start;
		if (start < 0)
			start = 0;
		System.arraycopy(buffer, start, out, 0, len);
		return out;
	}

	@Override
	public float max() {
		return max;
	}

	@Override
	public float min() {
		return min;
	}

	@Override
	public long size() {
		return buffer.length;
	}

	/**
	 * Get a single value, one based coordinate
	 * 
	 * @see net.sf.jannot.wiggle.Graph#value(int)
	 */
	@Override
	public float value(int pos) {
		return buffer[pos - 1];
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see net.sf.jannot.Data#get()
	 */
	@Override
	public Iterable<Float> get() {

		return new ArrayIterable<Float>(buffer);

	}

	/* (non-Javadoc)
	 * @see net.sf.jannot.Data#canSave()
	 */
	@Override
	public boolean canSave() {
		return false;
	}

}
